@@ -247,10 +247,12 @@ class R3sponse(object):
 
 	# a response object.
 	class ResponseObject(object):
-		def __init__(self):
-			self.success = False
-			self.message = None
-			self.error = None
+		def __init__(self, attributes={
+			"success":False,
+			"message":None,
+			"error":None,
+		}):
+			self.assign(attributes)
 		# iterate over self keys & variables.
 		def items(self):
 			return vars(self).items()
